@@ -26,19 +26,19 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <glade/glade.h>
 #include <dbus/dbus-glib.h>
 #include <libwnck/libwnck.h>
 
 #include <libxfce4util/libxfce4util.h>
-#include <libxfcegui4/libxfcegui4.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <xfconf/xfconf.h>
-#include "xfwm4-workspace-dialog_glade.h"
+#include "xfwm4-workspace-dialog_ui.h"
 #include "monitor-icon.h"
 
 #define WORKSPACES_CHANNEL         "xfwm4"
 
 #define WORKSPACE_NAMES_PROP       "/general/workspace_names"
+#define WORKSPACE_COUNT_PROP       "/general/workspace_count"
 
 static GdkNativeWindow opt_socket_id = 0;
 static gboolean opt_version = FALSE;
@@ -143,32 +143,17 @@ treeview_ws_names_cell_edited (GtkCellRendererText *cell,
 
 
 static void
-xfconf_workspace_names_changed(XfconfChannel *channel,
-                               const gchar *property,
-                               const GValue *value,
-                               gpointer user_data)
+xfconf_workspace_names_update(GPtrArray *names,
+                              GtkTreeView *treeview)
 {
-    GtkTreeView *treeview = user_data;
     GtkTreeModel *model = gtk_tree_view_get_model(treeview);
     WnckScreen *screen = wnck_screen_get_default();
-    gint i, n_workspaces;
-    GPtrArray *names;
+    guint i, n_workspaces;
     GtkTreePath *path;
     GtkTreeIter iter;
 
-    if(G_VALUE_TYPE(value) !=  dbus_g_type_get_collection("GPtrArray",
-                                                          G_TYPE_VALUE))
-    {
-        g_warning("(workspace names) Expected boxed GPtrArray property, got %s",
-                  G_VALUE_TYPE_NAME(value));
-        return;
-    }
+    g_return_if_fail(GTK_IS_TREE_VIEW(treeview));
 
-    names = g_value_get_boxed(value);
-    if(!names)
-        return;
-
-    wnck_screen_force_update(screen);
     n_workspaces = wnck_screen_get_workspace_count(screen);
     for(i = 0; i < n_workspaces && i < names->len; ++i) {
         GValue *val = g_ptr_array_index(names, i);
@@ -215,8 +200,52 @@ xfconf_workspace_names_changed(XfconfChannel *channel,
     gtk_tree_path_free(path);
 }
 
+
+
 static void
-workspace_dialog_setup_names_treeview(GladeXML *gxml,
+xfconf_workspace_names_changed(XfconfChannel *channel,
+                               const gchar *property,
+                               const GValue *value,
+                               gpointer user_data)
+{
+    GPtrArray *names;
+
+    if(G_VALUE_TYPE(value) !=  dbus_g_type_get_collection("GPtrArray",
+                                                          G_TYPE_VALUE))
+    {
+        g_warning("(workspace names) Expected boxed GPtrArray property, got %s",
+                  G_VALUE_TYPE_NAME(value));
+        return;
+    }
+
+    names = g_value_get_boxed(value);
+    if(!names)
+        return;
+
+    xfconf_workspace_names_update(names, user_data);
+}
+
+
+
+static void
+workspace_dialog_count_changed(GtkTreeView *treeview)
+{
+    GPtrArray *names;
+    XfconfChannel *channel;
+
+    channel = xfconf_channel_get(WORKSPACES_CHANNEL);
+
+    names = xfconf_channel_get_arrayv (channel, WORKSPACE_NAMES_PROP);
+    if(names != NULL)
+    {
+        xfconf_workspace_names_update(names, treeview);
+        xfconf_array_free(names);
+    }
+}
+
+
+static void
+workspace_dialog_setup_names_treeview(GtkBuilder *builder,
                                       XfconfChannel *channel)
 {
     GtkWidget *treeview, *dialog;
@@ -224,19 +253,17 @@ workspace_dialog_setup_names_treeview(GladeXML *gxml,
     GtkCellRenderer *render;
     GtkTreeViewColumn *col;
     WnckScreen *screen;
-    gint n_workspaces, i;
-    GtkTreeIter iter;
-    gchar **names;
 
-    dialog = glade_xml_get_widget(gxml, "change_name_dialog");
+    dialog = GTK_WIDGET (gtk_builder_get_object(builder, "change_name_dialog"));
     g_object_set_data(G_OBJECT(dialog), "name-entry",
-                      glade_xml_get_widget(gxml, "entry_name"));
+                      GTK_WIDGET (gtk_builder_get_object(builder, "entry_name")));
     g_signal_connect(G_OBJECT(dialog), "delete-event",
                      G_CALLBACK(gtk_true), NULL);
 
-    treeview = glade_xml_get_widget(gxml, "treeview_ws_names");
+    treeview = GTK_WIDGET (gtk_builder_get_object(builder, "treeview_ws_names"));
 
     ls = gtk_list_store_new(N_COLS, G_TYPE_INT, G_TYPE_STRING);
+    gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), GTK_TREE_MODEL(ls));
 
     render = gtk_cell_renderer_text_new();
     col = gtk_tree_view_column_new_with_attributes("", render,
@@ -259,31 +286,15 @@ workspace_dialog_setup_names_treeview(GladeXML *gxml,
     gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), col);
 
     screen = wnck_screen_get_default();
-    wnck_screen_force_update(screen);
-    names = xfconf_channel_get_string_list(channel, WORKSPACE_NAMES_PROP);
+    wnck_screen_force_update (screen);
 
-    n_workspaces = wnck_screen_get_workspace_count(screen);
-    i = 0;
-    for(; i < n_workspaces && names[i]; ++i) {
-        gtk_list_store_append(ls, &iter);
-        gtk_list_store_set(ls, &iter,
-                           COL_NUMBER, i + 1,
-                           COL_NAME, names[i],
-                           -1);
-    }
-    for(; i < n_workspaces; ++i) {
-        WnckWorkspace *space = wnck_screen_get_workspace(screen, i);
-        const char *name = wnck_workspace_get_name(space);
+    workspace_dialog_count_changed (GTK_TREE_VIEW (treeview));
 
-        gtk_list_store_append(ls, &iter);
-        gtk_list_store_set(ls, &iter,
-                           COL_NUMBER, i + 1,
-                           COL_NAME, name,
-                           -1);
-    }
-    g_strfreev(names);
-
-    gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), GTK_TREE_MODEL(ls));
+    /* watch ws count changes */
+    g_signal_connect_swapped(G_OBJECT(screen), "workspace-created",
+                             G_CALLBACK (workspace_dialog_count_changed), treeview);
+    g_signal_connect_swapped(G_OBJECT(screen), "workspace-destroyed",
+                             G_CALLBACK (workspace_dialog_count_changed), treeview);
 
     g_signal_connect(G_OBJECT(channel),
                      "property-changed::" WORKSPACE_NAMES_PROP,
@@ -291,7 +302,7 @@ workspace_dialog_setup_names_treeview(GladeXML *gxml,
 }
 
 static void
-workspace_dialog_configure_widgets (GladeXML *gxml,
+workspace_dialog_configure_widgets (GtkBuilder *builder,
                                     XfconfChannel *channel)
 {
     GtkWidget *vbox;
@@ -301,16 +312,16 @@ workspace_dialog_configure_widgets (GladeXML *gxml,
 
     gint wmax, hmax;
 
-    GtkWidget *workspace_count_spinbutton = glade_xml_get_widget (gxml, "workspace_count_spinbutton");
+    GtkWidget *workspace_count_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "workspace_count_spinbutton"));
 
-    GtkWidget *margin_top_spinbutton = glade_xml_get_widget (gxml, "margin_top_spinbutton");
-    GtkWidget *margin_right_spinbutton = glade_xml_get_widget (gxml, "margin_right_spinbutton");
-    GtkWidget *margin_bottom_spinbutton = glade_xml_get_widget (gxml, "margin_bottom_spinbutton");
-    GtkWidget *margin_left_spinbutton = glade_xml_get_widget (gxml, "margin_left_spinbutton");
+    GtkWidget *margin_top_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "margin_top_spinbutton"));
+    GtkWidget *margin_right_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "margin_right_spinbutton"));
+    GtkWidget *margin_bottom_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "margin_bottom_spinbutton"));
+    GtkWidget *margin_left_spinbutton = GTK_WIDGET (gtk_builder_get_object (builder, "margin_left_spinbutton"));
 
     /* Set monitor icon */
-    monitor = xfce_inline_icon_at_size (monitor_icon_data, -1, -1);
-    image = glade_xml_get_widget (gxml, "monitor_icon");
+    monitor = gdk_pixbuf_new_from_inline (-1, monitor_icon_data, TRUE, NULL);
+    image = GTK_WIDGET (gtk_builder_get_object (builder, "monitor_icon"));
     gtk_image_set_from_pixbuf (GTK_IMAGE (image), monitor);
     g_object_unref (monitor);
 
@@ -318,10 +329,10 @@ workspace_dialog_configure_widgets (GladeXML *gxml,
     wmax = gdk_screen_width () / 4;
     hmax = gdk_screen_height () / 4;
 
-    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_top_spinbutton), 0, wmax);
-    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_right_spinbutton), 0, hmax);
-    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_bottom_spinbutton), 0, wmax);
-    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_left_spinbutton), 0, hmax);
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_top_spinbutton), 0, hmax);
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_right_spinbutton), 0, wmax);
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_bottom_spinbutton), 0, hmax);
+    gtk_spin_button_set_range (GTK_SPIN_BUTTON (margin_left_spinbutton), 0, wmax);
 
     /* Bind easy properties */
     xfconf_g_property_bind (channel,
@@ -346,9 +357,9 @@ workspace_dialog_configure_widgets (GladeXML *gxml,
                             G_TYPE_INT,
                             (GObject *)margin_left_spinbutton, "value");
 
-    workspace_dialog_setup_names_treeview(gxml, channel);
+    workspace_dialog_setup_names_treeview(builder, channel);
 
-    vbox = glade_xml_get_widget (gxml, "main-vbox");
+    vbox = GTK_WIDGET (gtk_builder_get_object (builder, "main-vbox"));
 
     gtk_widget_show_all(vbox);
 }
@@ -365,7 +376,7 @@ static GOptionEntry entries[] =
 int
 main(int argc, gchar **argv)
 {
-    GladeXML *gxml;
+    GtkBuilder *builder;
     GtkWidget *dialog;
     GtkWidget *plug;
     GtkWidget *plug_child;
@@ -398,19 +409,24 @@ main(int argc, gchar **argv)
 
     channel = xfconf_channel_get(WORKSPACES_CHANNEL);
 
-    gxml = glade_xml_new_from_buffer (workspace_dialog_glade,
-                                      workspace_dialog_glade_length,
-                                      NULL, NULL);
+    if (xfce_titled_dialog_get_type () == 0)
+      return 1;
 
-    if(gxml) {
-        workspace_dialog_configure_widgets (gxml, channel);
+    builder = gtk_builder_new();
+    gtk_builder_add_from_string(builder, workspace_dialog_ui, workspace_dialog_ui_length, NULL);
+
+    if(builder) {
+        workspace_dialog_configure_widgets (builder, channel);
 
         if(opt_socket_id == 0) {
-            dialog = glade_xml_get_widget (gxml, "main-dialog");
+            dialog = GTK_WIDGET (gtk_builder_get_object (builder, "main-dialog"));
+            gtk_widget_show (dialog);
+            g_signal_connect (dialog, "response", G_CALLBACK (gtk_main_quit), NULL);
 
-            while(gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_HELP) {
-                /* FIXME: launch help */
-            }
+            /* To prevent the settings dialog to be saved in the session */
+            gdk_set_sm_client_id ("FAKE ID");
+
+            gtk_main ();
 
             gtk_widget_destroy(dialog);
         } else {
@@ -420,10 +436,13 @@ main(int argc, gchar **argv)
             gtk_widget_show (plug);
 
             /* Get plug child widget */
-            plug_child = glade_xml_get_widget (gxml, "plug-child");
+            plug_child = GTK_WIDGET (gtk_builder_get_object (builder, "plug-child"));
             gtk_widget_reparent (plug_child, plug);
             gtk_widget_show (plug_child);
 
+            /* To prevent the settings dialog to be saved in the session */
+            gdk_set_sm_client_id ("FAKE ID");
+
             /* Stop startup notification */
             gdk_notify_startup_complete ();
 
