@@ -354,9 +354,7 @@ xfwm_settings_class_init (XfwmSettingsClass *klass)
   xfwm_settings_parent_class = g_type_class_peek_parent (klass);
 
   gobject_class = G_OBJECT_CLASS (klass);
-#if GLIB_CHECK_VERSION (2,14,0)
   gobject_class->constructed = xfwm_settings_constructed;
-#endif
   gobject_class->finalize = xfwm_settings_finalize;
   gobject_class->get_property = xfwm_settings_get_property;
   gobject_class->set_property = xfwm_settings_set_property;
@@ -517,7 +515,7 @@ xfwm_settings_constructed (GObject *object)
     for (list_iter = children; list_iter != NULL; list_iter = g_list_next (list_iter))
       {
         button = GTK_WIDGET (list_iter->data);
-        name = gtk_widget_get_name (button);
+        name = gtk_buildable_get_name (GTK_BUILDABLE (button));
 
         if (name[strlen (name) - 1] == '|')
           {
@@ -542,36 +540,36 @@ xfwm_settings_constructed (GObject *object)
                           G_CALLBACK (xfwm_settings_signal_blocker), NULL);
         g_signal_connect (button, "focus",  G_CALLBACK (xfwm_settings_signal_blocker), NULL);
       }
+    g_list_free (children);
+
+    children = gtk_container_get_children (GTK_CONTAINER (hidden_box));
+    for (list_iter = children; list_iter != NULL; list_iter = g_list_next (list_iter))
+      {
+        button = GTK_WIDGET (list_iter->data);
+        name = gtk_buildable_get_name (GTK_BUILDABLE (button));
+
+        g_object_set_data (G_OBJECT (button), "key_char", (gpointer) &name[strlen (name) - 1]);
+        gtk_drag_source_set (button, GDK_BUTTON1_MASK, &target_entry[0], 1, GDK_ACTION_MOVE);
+
+          g_signal_connect (button, "drag_data_get",
+                            G_CALLBACK (xfwm_settings_title_button_drag_data), NULL);
+          g_signal_connect (button, "drag_begin", G_CALLBACK (xfwm_settings_title_button_drag_begin),
+                            NULL);
+          g_signal_connect (button, "drag_end", G_CALLBACK (xfwm_settings_title_button_drag_end),
+                            NULL);
+          g_signal_connect (button, "button_press_event",
+                            G_CALLBACK (xfwm_settings_signal_blocker), NULL);
+          g_signal_connect (button, "enter_notify_event",
+                            G_CALLBACK (xfwm_settings_signal_blocker), NULL);
+          g_signal_connect (button, "focus",  G_CALLBACK (xfwm_settings_signal_blocker), NULL);
+      }
+    g_list_free (children);
+
+    xfconf_channel_get_property (settings->priv->wm_channel, "/general/button_layout", &value);
+    xfwm_settings_button_layout_property_changed (settings->priv->wm_channel,
+                                                  "/general/button_layout", &value, settings);
+    g_value_unset (&value);
   }
-  g_list_free (children);
-
-  children = gtk_container_get_children (GTK_CONTAINER (hidden_box));
-  for (list_iter = children; list_iter != NULL; list_iter = g_list_next (list_iter))
-    {
-      button = GTK_WIDGET (list_iter->data);
-      name = gtk_widget_get_name (button);
-
-      g_object_set_data (G_OBJECT (button), "key_char", (gpointer) &name[strlen (name) - 1]);
-      gtk_drag_source_set (button, GDK_BUTTON1_MASK, &target_entry[0], 1, GDK_ACTION_MOVE);
-
-        g_signal_connect (button, "drag_data_get",
-                          G_CALLBACK (xfwm_settings_title_button_drag_data), NULL);
-        g_signal_connect (button, "drag_begin", G_CALLBACK (xfwm_settings_title_button_drag_begin),
-                          NULL);
-        g_signal_connect (button, "drag_end", G_CALLBACK (xfwm_settings_title_button_drag_end),
-                          NULL);
-        g_signal_connect (button, "button_press_event",
-                          G_CALLBACK (xfwm_settings_signal_blocker), NULL);
-        g_signal_connect (button, "enter_notify_event",
-                          G_CALLBACK (xfwm_settings_signal_blocker), NULL);
-        g_signal_connect (button, "focus",  G_CALLBACK (xfwm_settings_signal_blocker), NULL);
-    }
-  g_list_free (children);
-
-  xfconf_channel_get_property (settings->priv->wm_channel, "/general/button_layout", &value);
-  xfwm_settings_button_layout_property_changed (settings->priv->wm_channel,
-                                                "/general/button_layout", &value, settings);
-  g_value_unset (&value);
 
   /* Keyboard tab widgets */
   shortcuts_treeview = GTK_WIDGET (gtk_builder_get_object (settings->priv->builder, "shortcuts_treeview"));
@@ -794,10 +792,6 @@ xfwm_settings_new (void)
   if (G_LIKELY (builder != NULL))
     settings = g_object_new (XFWM_TYPE_SETTINGS, "gtk-builder", builder, NULL);
 
-#if !GLIB_CHECK_VERSION (2,14,0)
-  xfwm_settings_constructed (G_OBJECT(settings));
-#endif
-
   return settings;
 }
 
@@ -1113,11 +1107,7 @@ xfwm_settings_active_frame_drag_data (GtkWidget        *widget,
   g_return_if_fail (XFWM_IS_SETTINGS (settings));
 
   source = GTK_WIDGET (gtk_builder_get_object (settings->priv->builder,
-#if GTK_CHECK_VERSION (2,14,0)
                                  (const gchar *)gtk_selection_data_get_data (data)));
-#else
-                                 (const gchar *) data->data));
-#endif
   parent = gtk_widget_get_parent (source);
 
   active_box = GTK_WIDGET (gtk_builder_get_object (settings->priv->builder, "active-box"));
@@ -1240,11 +1230,7 @@ xfwm_settings_hidden_frame_drag_data (GtkWidget        *widget,
   g_return_if_fail (XFWM_IS_SETTINGS (settings));
 
   source = GTK_WIDGET (gtk_builder_get_object (settings->priv->builder,
-#if GTK_CHECK_VERSION (2,14,0)
                                  (const gchar *)gtk_selection_data_get_data (data)));
-#else
-                                 (const gchar *) data->data));
-#endif
   parent = gtk_widget_get_parent (source);
 
   hidden_box = GTK_WIDGET (gtk_builder_get_object (settings->priv->builder, "hidden-box"));
@@ -1350,10 +1336,13 @@ xfwm_settings_title_button_drag_data (GtkWidget        *widget,
                                       guint             info,
                                       guint             timestamp)
 {
+  const gchar *name;
+
+  name = gtk_buildable_get_name (GTK_BUILDABLE (widget));
+
   gtk_widget_hide (widget);
   gtk_selection_data_set (data, gdk_atom_intern ("_xfwm4_button_layout", FALSE), 8,
-                          (const guchar *)gtk_widget_get_name (widget),
-                          strlen (gtk_widget_get_name (widget)));
+                          (const guchar *)name, strlen (name));
 }
 
 
