@@ -295,21 +295,17 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
     eventFilterStatus status;
     ScreenInfo *screen_info;
     ScreenInfo *ev_screen_info;
-    gboolean handled;
     Client *c;
     int key;
 
     TRACE ("entering handleKeyEvent");
 
-    XAllowEvents (display_info->dpy, AsyncKeyboard, ev->time);
-
     ev_screen_info = myDisplayGetScreenFromRoot (display_info, ev->root);
     if (!ev_screen_info)
     {
         return EVENT_FILTER_PASS;
     }
 
-    handled = FALSE;
     status = EVENT_FILTER_PASS;
     c = clientGetFocus ();
     if (c)
@@ -520,6 +516,9 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
             break;
     }
 
+    /* Release pending events */
+    XAllowEvents (display_info->dpy, SyncKeyboard, CurrentTime);
+
     return status;
 }
 
@@ -528,6 +527,9 @@ handleKeyRelease (DisplayInfo *display_info, XKeyEvent * ev)
 {
     TRACE ("entering handleKeyRelease");
 
+    /* Release pending events */
+    XAllowEvents (display_info->dpy, SyncKeyboard, CurrentTime);
+
     return EVENT_FILTER_PASS;
 }
 
@@ -671,7 +673,6 @@ static void
 button1Action (Client * c, XButtonEvent * ev)
 {
     ScreenInfo *screen_info;
-    DisplayInfo *display_info;
     XEvent copy_event;
     XfwmButtonClickType tclick;
 
@@ -679,7 +680,6 @@ button1Action (Client * c, XButtonEvent * ev)
     g_return_if_fail (ev != NULL);
 
     screen_info = c->screen_info;
-    display_info = screen_info->display_info;
 
     if (!(c->type & WINDOW_TYPE_DONT_FOCUS))
     {
@@ -724,14 +724,12 @@ static void
 titleButton (Client * c, guint state, XButtonEvent * ev)
 {
     ScreenInfo *screen_info;
-    DisplayInfo *display_info;
 
     g_return_if_fail (c != NULL);
     g_return_if_fail (ev != NULL);
 
     /* Get Screen data from the client itself */
     screen_info = c->screen_info;
-    display_info = screen_info->display_info;
 
     if (ev->button == Button1)
     {
@@ -1036,7 +1034,7 @@ handleButtonPress (DisplayInfo *display_info, XButtonEvent * ev)
     }
 
     /* Release pending events */
-    XAllowEvents (display_info->dpy, replay ? ReplayPointer : SyncPointer, myDisplayGetCurrentTime (display_info));
+    XAllowEvents (display_info->dpy, replay ? ReplayPointer : SyncPointer, CurrentTime);
 
     return EVENT_FILTER_REMOVE;
 }
@@ -1056,7 +1054,7 @@ handleButtonRelease (DisplayInfo *display_info, XButtonEvent * ev)
     }
 
     /* Release pending events */
-    XAllowEvents (display_info->dpy, SyncPointer, myDisplayGetCurrentTime (display_info));
+    XAllowEvents (display_info->dpy, SyncPointer, CurrentTime);
 
     return EVENT_FILTER_REMOVE;
 }
@@ -1982,7 +1980,13 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         else if ((ev->message_type == display_info->atoms[WIN_LAYER]) && (ev->format == 32))
         {
             TRACE ("client \"%s\" (0x%lx) has received a WIN_LAYER event", c->name, c->window);
-            if ((unsigned long) ev->data.l[0] != c->win_layer)
+            /*
+             * Some apps that I wouldn't name try to manipulate the win layer by themselves
+             * and cause havoc when doing so on transient dialogs, so we need to be extra careful
+             * here before allowing apps to change the layer.
+             * Actually, I beleive twe should get rid of support of this old protocol...
+             */
+            if (!clientIsTransientOrModal(c) && ((unsigned long) ev->data.l[0] != c->win_layer))
             {
                 clientSetLayer (c, ev->data.l[0]);
             }
@@ -2820,10 +2824,10 @@ size_changed_cb(GdkScreen *gscreen, gpointer data)
 
         placeSidewalks (screen_info, screen_info->params->wrap_workspaces);
 
-        clientScreenResize (screen_info, FALSE);
-
         compositorUpdateScreenSize (screen_info);
     }
+
+    clientScreenResize (screen_info, FALSE);
 }
 
 /*
@@ -2872,14 +2876,14 @@ monitors_changed_cb(GdkScreen *gscreen, gpointer data)
                         screen_info->width, screen_info->height, screen_info->margins);
 
         placeSidewalks (screen_info, screen_info->params->wrap_workspaces);
-
-        clientScreenResize (screen_info, (screen_info->num_monitors < previous_num_monitors));
     }
 
     if (size_changed)
     {
         compositorUpdateScreenSize (screen_info);
     }
+
+    clientScreenResize (screen_info, (screen_info->num_monitors < previous_num_monitors));
 }
 
 void
