@@ -1,4 +1,4 @@
-/*      $Id: hints.c 28365 2008-10-22 20:10:00Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
         oroborus - (c) 2001 Ken Lynch
         Metacity - (c) 2001 Havoc Pennington
-        xfwm4    - (c) 2002-2008 Olivier Fourdan
+        xfwm4    - (c) 2002-2011 Olivier Fourdan
 
  */
 
@@ -151,7 +151,7 @@ unsigned int
 getWMProtocols (DisplayInfo *display_info, Window w)
 {
     Atom *protocols, *ap;
-    int i, n;
+    gint i, n;
     Atom atype;
     int aformat;
     unsigned int result;
@@ -197,7 +197,7 @@ getWMProtocols (DisplayInfo *display_info, Window w)
                     &aformat, &nitems, &bytes_remain,
                     (unsigned char **) &data)) == Success)
         {
-            for (i = 0, ap = (Atom *) data; i < nitems; i++, ap++)
+            for (i = 0, ap = (Atom *) data; (unsigned long) i < nitems; i++, ap++)
             {
                 if (*ap == display_info->atoms[WM_TAKE_FOCUS])
                 {
@@ -423,6 +423,7 @@ setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
     atoms[i++] = display_info->atoms[NET_WM_ALLOWED_ACTIONS];
     atoms[i++] = display_info->atoms[NET_WM_CONTEXT_HELP];
     atoms[i++] = display_info->atoms[NET_WM_DESKTOP];
+    atoms[i++] = display_info->atoms[NET_WM_FULLSCREEN_MONITORS];
     atoms[i++] = display_info->atoms[NET_WM_ICON];
     atoms[i++] = display_info->atoms[NET_WM_ICON_GEOMETRY];
     atoms[i++] = display_info->atoms[NET_WM_ICON_NAME];
@@ -589,6 +590,20 @@ setNetFrameExtents (DisplayInfo *display_info, Window w, int top, int left, int
                      XA_CARDINAL, 32, PropModeReplace, (unsigned char *) data, 4);
 }
 
+void
+setNetFullscreenMonitors (DisplayInfo *display_info, Window w, gint top, gint bottom, gint left, gint right)
+{
+    unsigned long data[4] = { 0, 0, 0, 0 };
+
+    TRACE ("entering setNetFullscreenMonitors");
+    data[0] = (unsigned long) top;;
+    data[1] = (unsigned long) bottom;
+    data[2] = (unsigned long) left;
+    data[3] = (unsigned long) right;
+    XChangeProperty (display_info->dpy, w, display_info->atoms[NET_WM_FULLSCREEN_MONITORS],
+                     XA_CARDINAL, 32, PropModeReplace, (unsigned char *) data, 4);
+}
+
 void
 initNetDesktopInfo (DisplayInfo *display_info, Window root, int workspace, int width, int height)
 {
@@ -698,7 +713,7 @@ get_text_property (DisplayInfo *display_info, Window w, Atom a)
 }
 
 static gboolean
-getUTF8StringData (DisplayInfo *display_info, Window w, int atom_id, gchar **str_p, int *length)
+getUTF8StringData (DisplayInfo *display_info, Window w, int atom_id, gchar **str_p, guint *length)
 {
     Atom type;
     int format;
@@ -736,7 +751,7 @@ getUTF8StringData (DisplayInfo *display_info, Window w, int atom_id, gchar **str
 }
 
 gboolean
-getUTF8String (DisplayInfo *display_info, Window w, int atom_id, gchar **str_p, int *length)
+getUTF8String (DisplayInfo *display_info, Window w, int atom_id, gchar **str_p, guint *length)
 {
     char *xstr;
 
@@ -775,12 +790,11 @@ getUTF8String (DisplayInfo *display_info, Window w, int atom_id, gchar **str_p,
 }
 
 gboolean
-getUTF8StringList (DisplayInfo *display_info, Window w, int atom_id, gchar ***str_p, int *n_items)
+getUTF8StringList (DisplayInfo *display_info, Window w, int atom_id, gchar ***str_p, guint *n_items)
 {
     char *xstr, *ptr;
     gchar **retval;
-    guint i;
-    int length;
+    guint i, length;
 
     g_return_val_if_fail (((atom_id >= 0) && (atom_id < ATOM_COUNT)), FALSE);
 
@@ -897,7 +911,7 @@ gboolean
 getWindowName (DisplayInfo *display_info, Window w, gchar **name)
 {
     char *str;
-    int len;
+    guint len;
     gboolean status;
 
     TRACE ("entering getWindowName");
@@ -964,7 +978,7 @@ getClientLeader (DisplayInfo *display_info, Window window)
 }
 
 gboolean
-getNetWMUserTime (DisplayInfo *display_info, Window window, guint32 *time)
+getNetWMUserTime (DisplayInfo *display_info, Window window, guint32 *timestamp)
 {
     Atom actual_type;
     int actual_format;
@@ -983,12 +997,12 @@ getNetWMUserTime (DisplayInfo *display_info, Window window, guint32 *time)
         if ((data) && (actual_type == XA_CARDINAL)
             && (nitems == 1) && (bytes_after == 0))
         {
-            *time = *((guint32 *) data);
+            *timestamp= *((guint32 *) data);
             XFree (data);
             return TRUE;
         }
     }
-    *time = 0;
+    *timestamp = (guint32) CurrentTime;
 
     return FALSE;
 }
@@ -1317,7 +1331,7 @@ gboolean
 getWindowStartupId (DisplayInfo *display_info, Window w, gchar **startup_id)
 {
     char *str;
-    int len;
+    guint len;
 
     TRACE ("entering getWindowStartupId");
 
