@@ -399,14 +399,12 @@ loadTheme (ScreenInfo *screen_info, Settings *rc)
     gchar *theme;
     const gchar *font;
     PangoFontDescription *desc;
-    PangoContext *context;
     guint i, j;
 
     widget = myScreenGetGtkWidget (screen_info);
     display_info = screen_info->display_info;
 
     desc = NULL;
-    context = NULL;
     i = 0;
 
     while (ui_part[i] && ui_state[i])
@@ -462,7 +460,6 @@ loadTheme (ScreenInfo *screen_info, Settings *rc)
     if (font && strlen (font))
     {
         desc = pango_font_description_from_string (font);
-        context = getUIPangoContext (widget);
         if (desc)
         {
             gtk_widget_modify_font (widget, desc);
@@ -568,11 +565,8 @@ loadKeyBindings (ScreenInfo *screen_info)
 {
     GList *shortcuts;
     gchar keyname[30];
-    Display *dpy;
     guint i;
 
-    dpy = myScreenGetXDisplay (screen_info);
-
     shortcuts = xfce_shortcuts_provider_get_shortcuts (screen_info->shortcuts_provider);
 
     parseShortcut (screen_info, KEY_CANCEL, "cancel_key", shortcuts);
@@ -879,9 +873,7 @@ loadSettings (ScreenInfo *screen_info)
 
     if (screen_info->workspace_count == 0)
     {
-        guint workspace_count;
-        workspace_count = MAX ((guint) getIntValue ("workspace_count", rc), 1);
-        workspaceSetCount (screen_info, workspace_count);
+        workspaceSetCount (screen_info, (guint) MAX (getIntValue ("workspace_count", rc), 1));
     }
 
     freeRc (rc);
@@ -1039,11 +1031,11 @@ initSettings (ScreenInfo *screen_info)
     }
     if (getHint (display_info, screen_info->xroot, NET_NUMBER_OF_DESKTOPS, &val))
     {
-        workspaceSetCount (screen_info, val);
+        workspaceSetCount (screen_info, (guint) MAX (val, 1));
     }
     else if (getHint (display_info, screen_info->xroot, WIN_WORKSPACE_COUNT, &val))
     {
-        workspaceSetCount (screen_info, val);
+        workspaceSetCount (screen_info, (guint) MAX (val, 1));
     }
 
     if (getUTF8StringList (display_info, screen_info->xroot, NET_DESKTOP_NAMES, &names, &i))
@@ -1156,7 +1148,7 @@ cb_xfwm4_channel_property_changed(XfconfChannel *channel, const gchar *property_
                 }
                 else if (!strcmp (name, "workspace_count"))
                 {
-                    workspaceSetCount(screen_info, g_value_get_int (value));
+                    workspaceSetCount(screen_info, (guint) MAX (g_value_get_int (value), 1));
                 }
                 else if (!strcmp (name, "frame_opacity"))
                 {
