@@ -544,6 +544,9 @@ clientAdjustFullscreenLayer (Client *c, gboolean set)
 {
     g_return_val_if_fail (c, FALSE);
 
+    TRACE ("entering clientAdjustFullscreenLayer");
+    TRACE ("%s fullscreen layer for  \"%s\" (0x%lx)", set ? "Setting" : "Unsetting", c->name, c->window);
+
     if (set)
     {
         if (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN)
@@ -555,17 +558,16 @@ clientAdjustFullscreenLayer (Client *c, gboolean set)
     }
     else if (c->win_layer == WIN_LAYER_FULLSCREEN)
     {
-        if (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN)
-            || FLAG_TEST(c->flags, CLIENT_FLAG_FULLSCREEN))
+        if (FLAG_TEST(c->flags, CLIENT_FLAG_FULLSCREEN))
         {
-            if (FLAG_TEST(c->flags, CLIENT_FLAG_FULLSCREEN))
-            {
-                clientSetLayer (c, c->fullscreen_old_layer);
-            }
-            else
-            {
-                clientSetLayer (c, WIN_LAYER_NORMAL);
-            }
+            TRACE ("Moving \"%s\" (0x%lx) to initial layer %d", c->name, c->window, c->fullscreen_old_layer);
+            clientSetLayer (c, c->fullscreen_old_layer);
+            return TRUE;
+        }
+        if (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_LEGACY_FULLSCREEN))
+        {
+            TRACE ("Moving \"%s\" (0x%lx) to layer %d", c->name, c->window, WIN_LAYER_FULLSCREEN);
+            clientSetLayer (c, WIN_LAYER_NORMAL);
             return TRUE;
         }
     }
